==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/GetUBAEnd.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+8)
#define CT_v193	((void*)startLabel+36)
#define F0_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+44)
#define FN_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+56)
#define CT_v195	((void*)startLabel+80)
#define CF_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+88)
#define CT_v197	((void*)startLabel+144)
#define FN_LAMBDA190	((void*)startLabel+180)
#define CT_v199	((void*)startLabel+204)
#define F0_LAMBDA190	((void*)startLabel+212)
#define ST_v196	((void*)startLabel+220)
#define ST_v198	((void*)startLabel+243)
#define ST_v194	((void*)startLabel+272)
#define ST_v192	((void*)startLabel+298)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95getUBAEnd_35(void);
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node TM_NHC_46BinArray[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v193)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v192)
,	/* CT_v193: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v195)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v194)
,	/* CT_v195: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v197)
,};
Node FN_NHC_46BinArray_46getUBAEnd[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG,1,HEAP_CVAL_I5)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,3,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 130001
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAEnd[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAEnd),1)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA190),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v199)
,	/* FN_LAMBDA190: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140014
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA190: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA190),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v196: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,69)
,	/* ST_v198: (byte 3) */
  bytes2word(110,100,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,58,49,52)
,	/* ST_v194: (byte 4) */
  bytes2word(58,49,52,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
,	/* ST_v192: (byte 2) */
  bytes2word(100,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,104)
, bytes2word(115,95,103,101)
, bytes2word(116,85,66,65)
, bytes2word(69,110,100,35)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAEnd" NHC.BinArray.hs_getUBAEnd# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAEnd(void*);
#ifdef PROFILE
static SInfo pf_hs_getUBAEnd = {"NHC.BinArray","NHC.BinArray.hs_getUBAEnd#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAEnd_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAEnd(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getUBAEnd);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/GetUBAEnd.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+8)
#define CT_v197	((void*)startLabel+36)
#define F0_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+44)
#define FN_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+56)
#define CT_v199	((void*)startLabel+80)
#define CF_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+88)
#define CT_v201	((void*)startLabel+144)
#define FN_LAMBDA194	((void*)startLabel+180)
#define CT_v203	((void*)startLabel+204)
#define F0_LAMBDA194	((void*)startLabel+212)
#define ST_v200	((void*)startLabel+220)
#define ST_v202	((void*)startLabel+243)
#define ST_v198	((void*)startLabel+278)
#define ST_v196	((void*)startLabel+304)
extern Node TM_NHC_46BinArray[];
void FR_NHC_46BinArray_46hs_95getUBAEnd_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46BinArray[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v197)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd_35),1)
, bytes2word(0,0,0,0)
, useLabel(CT_v199)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v201)
,};
Node FN_NHC_46BinArray_46getUBAEnd[] = {
  useLabel(TM_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG,1,HEAP_CVAL_I5)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,6,HEAP_OFF_N1)
, bytes2word(5,HEAP_OFF_N1,3,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 130001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAEnd[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAEnd),1)
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v203)
,	/* FN_LAMBDA194: (byte 0) */
  useLabel(TMSUB_NHC_46BinArray)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 140014
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v200: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,69)
,	/* ST_v202: (byte 3) */
  bytes2word(110,100,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,58,49,52)
, bytes2word(58,49,52,45)
, bytes2word(49,52,58,50)
,	/* ST_v198: (byte 2) */
  bytes2word(57,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,104)
, bytes2word(115,95,103,101)
, bytes2word(116,85,66,65)
,	/* ST_v196: (byte 4) */
  bytes2word(69,110,100,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,35,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAEnd" NHC.BinArray.hs_getUBAEnd# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAEnd(void*);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95getUBAEnd_35 = {"NHC.BinArray","NHC.BinArray.hs_getUBAEnd#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAEnd_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAEnd(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95getUBAEnd_35);
  C_RETURN(nodeptr);
}
